@@ -21,7 +21,7 @@ use Scalar::Util ();		# Core since 5.7.3
 use Storable ();		# Core since 5.7.3
 use Test::Builder ();		# Core since 5.6.2
 
-our $VERSION = '0.000_908';
+our $VERSION = '0.000_909';
 
 use constant ON_DARWIN		=> 'darwin' eq $^O;
 use constant ON_VMS		=> 'VMS' eq $^O;
@@ -249,6 +249,11 @@ sub all_pod_files_ok {
     @dir
 	or push @dir, 'blib';
 
+    my $note = sprintf 'all_pod_files_ok( %s )',
+	join ', ', map { "'$_'" } @dir;
+
+    $TEST->note( "Begin $note" );
+
     my ( $fail, $pass, $skip ) = ( 0 ) x 3;
 
     File::Find::find( {
@@ -266,6 +271,9 @@ sub all_pod_files_ok {
 	},
 	@dir,
     );
+
+    $TEST->note( "End $note" );
+
     return wantarray ? ( $fail, $pass, $skip ) : $fail;
 }
 
@@ -525,7 +533,6 @@ sub _handle_man {
 	    ( [^(]+ ) (?: [(] ( [^)]+ ) [)] )? /smx
 	or return $self->_fail( $link, 'not recognized as man page spec' );
 
-    $page =~ s/ \A \s+ //smx;
     $page =~ s/ \s+ \z //smx;
 
     $page =~ m/ \s /smx
@@ -847,6 +854,8 @@ use Pod::Simple::PullParser;	# Core since 5.9.3 (part of Pod::Simple)
 
 @My_Parser::ISA = qw{ Pod::Simple::PullParser };
 
+my %section_tag = map { $_ => 1 } qw{ head1 head2 head3 head4 item-text };
+
 sub new {
     my ( $class ) = @_;
     my $self = $class->SUPER::new();
@@ -878,6 +887,16 @@ sub _attr {
     return $self->{ ( __PACKAGE__ ) } ||= {};
 }
 
+sub _normalize_text {
+    my ( $text ) = @_;
+    defined $text
+	or $text = '';
+    $text =~ s/ \A \s+ //smx;
+    $text =~ s/ \s+ \z //smx;
+    $text =~ s/ \s+ / /smxg;
+    return $text;
+}
+
 sub __token_start {
     my ( $self, $token ) = @_;
     my $attr = $self->_attr();
@@ -887,8 +906,13 @@ sub __token_start {
     my $tag = $token->tag();
     if ( 'L' eq $tag ) {
 	$token->attr( line_number => $self->{My_Parser}{line} );
+	foreach my $name ( qw{ section to } ) {
+	    my $sect = $token->attr( $name )
+		or next;
+	    @{ $sect }[ 2 .. $#$sect ] = ( _normalize_text( "$sect" ) );
+	}
 	push @{ $attr->{links} }, [ @{ $token }[ 1 .. $#$token ] ];
-    } elsif ( $tag =~ m/ \A head [1-9] \z /smx ) {
+    } elsif ( $section_tag{$tag} ) {
 	$attr->{text} = '';
     }
     return;
@@ -907,8 +931,8 @@ sub __token_end {
     my ( $self, $token ) = @_;
     my $attr = $self->_attr();
     my $tag = $token->tag();
-    if ( $tag =~ m/ \A head [1-9] \z /smx ) {
-	$attr->{sections}{ delete $attr->{text} } = 1;
+    if ( $section_tag{$tag} ) {
+	$attr->{sections}{ _normalize_text( delete $attr->{text} ) } = 1;
     }
     return;
 }
@@ -951,6 +975,20 @@ This module should probably be considered alpha-quality code at this
 point. It checks most of my modest corpus (correctly, I hope), but
 beyond that deponent sayeth not.
 
+One thing L<perlpod|perlpod> is silent on (at least, I could not find
+anything about it) is how (or even whether) to normalize links and
+section names. Maybe I looked in the wrong place?
+
+Anyhow, because Meta CPAN has been observed to link
+
+ L<SOME
+ SECTION>
+
+to C<=head1 SOME SECTION>, this module normalizes both link and section
+names by removing leading and trailing white space, and replacing
+embedded white space with a single space. Yes, I know that Meta CPAN's
+observed handling of POD is B<far> from being definitive.
+
 This module started its life as a low-dependency version of
 L<Test::Pod::LinkCheck|Test::Pod::LinkCheck>. Significant
 differences from that module include:
